@@ -1,28 +1,31 @@
-/*********************************************************************
- * Copyright (c) 2019 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import { Command, flags } from '@oclif/command'
 import { boolean } from '@oclif/command/lib/flags'
 import { cli } from 'cli-ux'
 import * as Listrq from 'listr'
+import Listr = require('listr')
 
 import { ChectlContext } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
-import { assumeYes, batch, cheDeployment, cheNamespace, CHE_TELEMETRY, devWorkspaceControllerNamespace, listrRenderer, skipKubeHealthzCheck } from '../../common-flags'
+import { assumeYes, batch, cheDeployment, cheNamespace, CHE_TELEMETRY, listrRenderer, skipKubeHealthzCheck } from '../../common-flags'
 import { DEFAULT_ANALYTIC_HOOK_NAME } from '../../constants'
 import { CheTasks } from '../../tasks/che'
 import { DevWorkspaceTasks } from '../../tasks/component-installers/devfile-workspace-operator-installer'
 import { OLMTasks } from '../../tasks/installers/olm'
 import { OperatorTasks } from '../../tasks/installers/operator'
 import { ApiTasks } from '../../tasks/platforms/api'
-import { findWorkingNamespace, getCommandErrorMessage, getCommandSuccessMessage, notifyCommandCompletedSuccessfully } from '../../util'
+import { findWorkingNamespace, getCommandSuccessMessage, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
 
 export default class Delete extends Command {
   static description = 'delete any CodeReady Workspaces related resource'
@@ -31,10 +34,9 @@ export default class Delete extends Command {
     help: flags.help({ char: 'h' }),
     chenamespace: cheNamespace,
     batch,
-    'dev-workspace-controller-namespace': devWorkspaceControllerNamespace,
     'delete-namespace': boolean({
       description: 'Indicates that a CodeReady Workspaces namespace will be deleted as well',
-      default: false
+      default: false,
     }),
     'deployment-name': cheDeployment,
     'listr-renderer': listrRenderer,
@@ -45,12 +47,13 @@ export default class Delete extends Command {
     }),
     'skip-kubernetes-health-check': skipKubeHealthzCheck,
     yes: assumeYes,
-    telemetry: CHE_TELEMETRY
+    telemetry: CHE_TELEMETRY,
   }
 
   async run() {
     const { flags } = this.parse(Delete)
     const ctx = await ChectlContext.initAndGet(flags, this)
+
     flags.chenamespace = await findWorkingNamespace(flags)
 
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Delete.id, flags })
@@ -61,19 +64,30 @@ export default class Delete extends Command {
     }
 
     const apiTasks = new ApiTasks()
+    const kube = new KubeHelper(flags)
     const operatorTasks = new OperatorTasks()
     const olmTasks = new OLMTasks()
     const cheTasks = new CheTasks(flags)
     const devWorkspaceTasks = new DevWorkspaceTasks(flags)
 
     const tasks = new Listrq([], ctx.listrOptions)
-
-    tasks.add(apiTasks.testApiTasks(flags, this))
+    tasks.add(apiTasks.testApiTasks(flags))
     tasks.add(operatorTasks.deleteTasks(flags))
     tasks.add(olmTasks.deleteTasks(flags))
     tasks.add(cheTasks.deleteTasks(flags))
-    tasks.add(devWorkspaceTasks.getUninstallTasks())
     tasks.add(cheTasks.waitPodsDeletedTasks())
+
+    // Remove devworkspace controller only if there are no more cheClusters after olm/operator tasks
+    tasks.add({
+      title: 'Uninstall DevWorkspace Controller and DevWorkspace Che Controller',
+      task: async (_ctx: any, task: any) => {
+        const checlusters = await kube.getAllCheClusters()
+        if (checlusters.length === 0) {
+          return new Listr(devWorkspaceTasks.getUninstallTasks())
+        }
+        task.title = `${task.title}...Skipped: another CodeReady Workspaces deployment found.`
+      }})
+
     if (flags['delete-namespace']) {
       tasks.add(cheTasks.deleteNamespace(flags))
     }
@@ -83,7 +97,7 @@ export default class Delete extends Command {
         await tasks.run()
         cli.log(getCommandSuccessMessage())
       } catch (err) {
-        this.error(getCommandErrorMessage(err))
+        this.error(wrapCommandError(err))
       }
     } else {
       this.exit(0)
@@ -94,7 +108,9 @@ export default class Delete extends Command {
   }
 
   async isDeletionConfirmed(flags: any): Promise<boolean> {
-    const cluster = KubeHelper.KUBE_CONFIG.getCurrentCluster()
+    const kc = new KubeHelper(flags)
+    const cluster = kc.kubeConfig.getCurrentCluster()
+
     if (!cluster) {
       throw new Error('Failed to get current Kubernetes cluster. Check if the current context is set via kubectl/oc')
     }
