@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import * as fs from 'fs-extra'
 import * as Listr from 'listr'
@@ -24,12 +26,14 @@ export const DEFAULT_CHE_CLUSTER_ISSUER_NAME = 'che-cluster-issuer'
 
 export class CertManagerTasks {
   protected kubeHelper: KubeHelper
+
   protected cheHelper: CheHelper
 
   constructor(flags: any) {
     this.kubeHelper = new KubeHelper(flags)
     this.cheHelper = new CheHelper(flags)
   }
+
   /**
    * Verify if cert-manager is installed in cluster
    */
@@ -39,20 +43,20 @@ export class CertManagerTasks {
         title: 'Check Cert Manager deployment',
         task: async (ctx: any, task: any) => {
           // Check only one CRD of cert-manager assuming that it is installed or not.
-          ctx.certManagerInstalled = await this.kubeHelper.getNamespace(CERT_MANAGER_NAMESPACE_NAME) && await this.kubeHelper.isCrdV1Exists('certificates.cert-manager.io')
+          ctx.certManagerInstalled = await this.kubeHelper.getNamespace(CERT_MANAGER_NAMESPACE_NAME) && await this.kubeHelper.getCrd('certificates.cert-manager.io')
           if (ctx.certManagerInstalled) {
             task.title = `${task.title}...already deployed`
           } else {
             task.title = `${task.title}...not deployed`
           }
-        }
+        },
       },
       {
         title: 'Deploy cert-manager',
         enabled: ctx => !ctx.certManagerInstalled,
         task: async (ctx: any, task: any) => {
           let yamlPath = path.join(flags.templates, 'cert-manager', 'cert-manager.yaml')
-          if (! await fs.pathExists(yamlPath)) {
+          if (!await fs.pathExists(yamlPath)) {
             // Older Che versions don't have Cert Manager install yaml in templates
             // Try to use embedded in crwctl version
             yamlPath = path.join(__dirname, '../../../installers/cert-manager.yml')
@@ -62,7 +66,7 @@ export class CertManagerTasks {
           ctx.certManagerInstalled = true
 
           task.title = `${task.title}...done`
-        }
+        },
       },
       {
         title: 'Wait for cert-manager',
@@ -80,10 +84,11 @@ export class CertManagerTasks {
           await this.kubeHelper.waitForPodReady('app.kubernetes.io/name=cainjector', CERT_MANAGER_NAMESPACE_NAME, 1000, timeout)
 
           task.title = `${task.title}...ready`
-        }
+        },
       },
     ]
   }
+
   /**
    * Returns list of tasks which perform cert-manager checks and requests self-signed certificate for Che.
    */
@@ -141,7 +146,7 @@ export class CertManagerTasks {
           } else {
             task.title = `${task.title}...already exists`
           }
-        }
+        },
       },
       {
         title: 'Set up CodeReady Workspaces certificates issuer',
@@ -175,7 +180,7 @@ export class CertManagerTasks {
           } else {
             task.title = `${task.title}...already exists`
           }
-        }
+        },
       },
       {
         title: 'Request certificate',
@@ -203,7 +208,7 @@ export class CertManagerTasks {
           ctx.cheCertificateExists = true
 
           task.title = `${task.title}...done`
-        }
+        },
       },
       {
         title: 'Wait for certificate',
@@ -215,7 +220,7 @@ export class CertManagerTasks {
           await this.kubeHelper.waitSecret(CHE_TLS_SECRET_NAME, flags.chenamespace, ['tls.key', 'tls.crt', 'ca.crt'])
 
           task.title = `${task.title}...ready`
-        }
+        },
       },
       {
         title: 'Retrieving Che CA certificate',
@@ -230,7 +235,7 @@ export class CertManagerTasks {
             const cheCaCertPath = await this.cheHelper.saveCheCaCert(cheCaCrt)
 
             // We need to put self-signed CA certificate separately into CHE_ROOT_CA_SECRET_NAME secret
-            await this.kubeHelper.createSecret(CHE_ROOT_CA_SECRET_NAME, { 'ca.crt': cheCaCrt }, flags.chenamespace)
+            await this.kubeHelper.createSecret(flags.chenamespace, CHE_ROOT_CA_SECRET_NAME, { 'ca.crt': cheCaCrt })
 
             const serverStrategy = await this.kubeHelper.getConfigMapValue('che', flags.chenamespace, 'CHE_INFRA_KUBERNETES_SERVER__STRATEGY')
             if (serverStrategy !== 'single-host') {
@@ -240,9 +245,8 @@ export class CertManagerTasks {
           } else {
             throw new Error('Failed to get Cert Manager CA secret')
           }
-        }
-      }
+        },
+      },
     ]
   }
-
 }
